@@ -1,6 +1,6 @@
 package VM::JiffyBox;
 {
-  $VM::JiffyBox::VERSION = '0.022';
+  $VM::JiffyBox::VERSION = '0.0232';
 }
 
 # The line below is recognised by Dist::Zilla and taken for CPAN packaging
@@ -9,6 +9,7 @@ package VM::JiffyBox;
 use Moo;
 use JSON;
 use LWP::UserAgent;
+use Scalar::Util qw( reftype );
 
 use VM::JiffyBox::Box;
 
@@ -59,11 +60,24 @@ sub get_id_from_name {
     
     my $details = $self->get_details;
 
+    # EXIT if no details
+    return 0 unless $details;
+
     $self->last         ( $details );
+
+    # EXIT if no expected result
+    return 0 unless (reftype $details eq 'HASH');
+    return 0 unless (exists $details->{result});
+    return 0 unless (reftype $details->{result} eq 'HASH');
+
     $self->details_cache( $details );
     
     # look for a match in the results
     foreach my $box (values %{$details->{result}}) {
+
+        # EXIT if no expected result
+        return 0 unless (reftype $box eq 'HASH');
+
         return $box->{id} if ($box->{name} eq $box_name);
     }
 
@@ -128,7 +142,7 @@ VM::JiffyBox - OO-API for JiffyBox Virtual Machine
 
 =head1 VERSION
 
-version 0.022
+version 0.0232
 
 =head1 SYNOPSIS
 
